==> drd-8.x-3.0.tar.gz: drd/src/Entity/ReleaseInterface.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\ReleaseInterface.
 */

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Release entities.
 *
 * @ingroup drd
 */
interface ReleaseInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * @param bool $flag
   * @return bool
   */
  public function isJustCreated($flag = NULL);

  /**
   * Gets the Release version.
   *
   * @return string
   *   Version of the Release.
   */
  public function getVersion();

  /**
   * Sets the Release version.
   *
   * @param string $version
   *   The Release version.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface
   *   The called Release entity.
   */
  public function setVersion($version);

  /**
   * Gets the Release Major Version.
   *
   * @return Major
   *   Major Version of the Release.
   */
  public function getMajor();

  /**
   * Sets the Release Major Version.
   *
   * @param Major $major
   *   The Release Major Version.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface
   *   The called Release entity.
   */
  public function setMajor($major);

  /**
   * Gets the Release creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Release.
   */
  public function getCreatedTime();

  /**
   * Sets the Release creation timestamp.
   *
   * @param int $timestamp
   *   The Release creation timestamp.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface
   *   The called Release entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Release published status indicator.
   *
   * Unpublished Release are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Release is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Release.
   *
   * @param bool $published
   *   TRUE to set this Release to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\Entity\ReleaseInterface
   *   The called Release entity.
   */
  public function setPublished($published);

  /**
   * @param string $type
   * @param string $name
   * @param string $version
   * @return \Drupal\drd\Entity\ReleaseInterface
   */
  public static function findOrCreate($type, $name, $version);

  /**
   * @return string
   */
  public function getProjectType();

  /**
   * @return \Drupal\Core\Url
   */
  public function getProjectLink();

  /**
   * @return \Drupal\Core\Url
   */
  public function getReleaseLink();

  /**
   * @return \Drupal\Core\Url
   */
  public function getDownloadLink();

}

==> drd-8.x-3.4.tar.gz: drd/src/Entity/ReleaseInterface.php <==
<?php

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Url;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Release entities.
 *
 * @ingroup drd
 */
interface ReleaseInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * @param bool $flag
   * @return bool
   */
  public function isJustCreated($flag = NULL);

  /**
   * Gets the Release version.
   *
   * @return string
   *   Version of the Release.
   */
  public function getVersion();

  /**
   * Gets the Release version without the optional leadin "8.x-".
   *
   * @return string
   *   Version of the Release.
   */
  public function getReleaseVersion();

  /**
   * Sets the Release version.
   *
   * @param string $version
   *   The Release version.
   *
   * @return ReleaseInterface
   *   The called Release entity.
   */
  public function setVersion($version);

  /**
   * Gets the Release Major Version.
   *
   * @return MajorInterface
   *   Major Version of the Release.
   */
  public function getMajor();

  /**
   * Sets the Release Major Version.
   *
   * @param MajorInterface $major
   *   The Release Major Version.
   *
   * @return ReleaseInterface
   *   The called Release entity.
   */
  public function setMajor($major);

  /**
   * Gets the Release creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Release.
   */
  public function getCreatedTime();

  /**
   * Sets the Release creation timestamp.
   *
   * @param int $timestamp
   *   The Release creation timestamp.
   *
   * @return ReleaseInterface
   *   The called Release entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Release published status indicator.
   *
   * Unpublished Release are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Release is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Release.
   *
   * @param bool $published
   *   TRUE to set this Release to published, FALSE to set it to unpublished.
   *
   * @return ReleaseInterface
   *   The called Release entity.
   */
  public function setPublished($published);

  /**
   * @param string $type
   * @param string $name
   * @param string $version
   * @return ReleaseInterface
   */
  public static function findOrCreate($type, $name, $version);

  /**
   * @return string
   */
  public function getProjectType();

  /**
   * @return Url
   */
  public function getProjectLink();

  /**
   * @return Url
   */
  public function getReleaseLink();

  /**
   * @return Url
   */
  public function getDownloadLink();

}
